Claude Skills for use with Obsidian.

## Installation

Add the contents of this repo to a `/.claude` folder in the root of your Obsidian vault (or whichever folder you're using with Claude Code). See more in the [official Claude Skills documentation](https://platform.claude.com/docs/en/agents-and-tools/agent-skills/overview).

## Skills

### Create and edit Obsidian-compatible plain text files

- [Obsidian Flavored Markdown](https://help.obsidian.md/obsidian-flavored-markdown) `.md`
- [Obsidian Bases](https://help.obsidian.md/bases/syntax) `.base`
- [JSON Canvas](https://jsoncanvas.org/) `.canvas`
